pub enum ExecuteError {
Http(Error),
Payload(PayloadError),
Response(ResponseError),
}Expand description
Represents errors that can occur during the execution of a method using the Telegram Bot API client.
Variants
Http(Error)
An error indicating a failure to send an HTTP request.
Payload(PayloadError)
An error indicating a failure to build an HTTP request payload.
Response(ResponseError)
An error received from the Telegram server in response to the execution request.