pub struct BusinessOpeningHoursInterval {
pub opening_minute: Integer,
pub closing_minute: Integer,
}Expand description
Provides information about the time interval describing business opening hours.
Fields
opening_minute: IntegerThe minute’s sequence number in a week, starting on Monday, marking the start of the time interval during which the business is open; 0 - 7 24 60.
closing_minute: IntegerThe minute’s sequence number in a week, starting on Monday, marking the end of the time interval during which the business is open; 0 - 8 24 60.
Implementations