pub struct ChecklistTasksDone {
pub checklist_message: Option<Box<Message>>,
pub marked_as_done_task_ids: Option<Vec<Integer>>,
pub marked_as_not_done_task_ids: Option<Vec<Integer>>,
}Expand description
Describes a service message about checklist tasks marked as done or not done.
Fields
checklist_message: Option<Box<Message>>Message containing the checklist whose tasks were marked as done or not done.
Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
marked_as_done_task_ids: Option<Vec<Integer>>Identifiers of the tasks that were marked as done.
marked_as_not_done_task_ids: Option<Vec<Integer>>Identifiers of the tasks that were marked as not done.
Implementations
Sourceimpl ChecklistTasksDone
impl ChecklistTasksDone
Sourcepub fn with_checklist_message(self, value: Message) -> Self
pub fn with_checklist_message(self, value: Message) -> Self
Sets a new checklist message.
Arguments
value- Message containing the checklist whose tasks were marked as done or not done.
Sourcepub fn with_marked_as_done_task_ids<T>(self, value: T) -> Selfwhere
T: IntoIterator<Item = Integer>,
pub fn with_marked_as_done_task_ids<T>(self, value: T) -> Selfwhere
T: IntoIterator<Item = Integer>,
Sets a new list of task identifiers.
Arguments
value- Identifiers of the tasks that were marked as done.
Sourcepub fn with_marked_as_not_done_task_ids<T>(self, value: T) -> Selfwhere
T: IntoIterator<Item = Integer>,
pub fn with_marked_as_not_done_task_ids<T>(self, value: T) -> Selfwhere
T: IntoIterator<Item = Integer>,
Sets a new list of task identifiers.
Arguments
value- Identifiers of the tasks that were marked as not done.