CreateInvoiceLink

Struct CreateInvoiceLink 

pub struct CreateInvoiceLink { /* private fields */ }
Creates a link for an invoice.

Returns the created invoice link as String on success.

Implementations

pub fn new<A, B, C, D, E>( title: A, description: B, payload: C, currency: D, prices: E, ) -> Self
where A: Into<String>, B: Into<String>, C: Into<String>, D: Into<String>, E: IntoIterator<Item = LabeledPrice>,

Creates a new CreateInvoiceLink.

Arguments
  • title - Product name; 1-32 characters.
  • description - Product description; 1-255 characters.
  • payload - Bot-defined invoice payload; 1-128 bytes; this will not be displayed to the user; use for your internal processes.
  • currency - Three-letter ISO 4217 currency code, see more on currencies.
  • prices - Price breakdown (e.g. product price, tax, discount, delivery cost, delivery tax, bonus, etc.).
pub fn with_business_connection_id<T>(self, value: T) -> Self
where T: Into<String>,

Sets a new business connection ID.

Arguments
  • value - Unique identifier of the business connection on behalf of which the link will be created.
pub fn with_parameters(self, value: InvoiceParameters) -> Self

Sets a new invoice parameters.

Arguments
  • value - Invoice parameters.
pub fn with_subscription_period(self, value: Integer) -> Self

Sets a new subscription period.

Arguments
  • value - The number of seconds the subscription will be active for before the next payment. The currency must be set to “XTR” (Telegram Stars) if the parameter is used. Currently, it must always be 2592000 (30 days) if specified.