pub struct DeleteBusinessMessages { /* private fields */ }Expand description
Deletes messages on behalf of a business account.
Requires the can_delete_outgoing_messages business bot right to delete messages sent by the bot itself,
or the can_delete_all_messages business bot right to delete any message.
Implementations
Sourceimpl DeleteBusinessMessages
impl DeleteBusinessMessages
Sourcepub fn new<A, B>(business_connection_id: A, message_ids: B) -> Self
pub fn new<A, B>(business_connection_id: A, message_ids: B) -> Self
Creates a new DeleteBusinessMessages.
Arguments
business_connection_id- Unique identifier of the business connection on behalf of which to delete the messages.message_ids- A list of 1-100 identifiers of messages to delete; all messages must be from the same chat; see deleteMessage for limitations on which messages can be deleted.