pub struct DeleteChatStickerSet { /* private fields */ }Expand description
Deletes a group sticker set from a supergroup.
The bot must be an administrator in the chat for this to work and must have the appropriate admin rights.
Use the field can_set_sticker_set optionally returned
in crate::types::GetChat requests to check if the bot can use this method.
Implementations