ForwardMessages

Struct ForwardMessages 

pub struct ForwardMessages { /* private fields */ }
Forwards multiple messages.

If some of the specified messages can’t be found or forwarded, they are skipped. Service messages and messages with protected content can’t be forwarded. Album grouping is kept for forwarded messages.

Implementations

Source

impl ForwardMessages

pub fn new<A, B, C>(chat_id: A, from_chat_id: B, message_ids: C) -> Self
where A: Into<ChatId>, B: Into<ChatId>, C: IntoIterator<Item = Integer>,

Creates a new ForwardMessages.

Arguments
  • chat_id - Unique identifier of the target chat.
  • from_chat_id - Unique identifier for the chat where the original message was sent.
  • message_ids - Identifiers of 1-100 messages in the chat from_chat_id to forward; the identifiers must be specified in a strictly increasing order.
pub fn with_direct_messages_topic_id(self, value: Integer) -> Self

Sets a new direct messages topic ID

  • value - Identifier of the direct messages topic to which the message will be sent.

Required if the message is sent to a direct messages chat.

pub fn with_disable_notification(self, value: bool) -> Self

Sets a new value for the disable_notification flag.

Arguments
  • value - Indicates whether to send the message silently or not; a user will receive a notification without sound.
pub fn with_message_thread_id(self, value: Integer) -> Self

Sets a new message thread ID.

Arguments
  • value - Unique identifier of the target message thread; for forum supergroups and private chats of bots with forum topic mode enabled only.
pub fn with_protect_content(self, value: bool) -> Self

Sets a new value for the protect_content flag.

Arguments
  • value - Indicates whether to protect the contents of the sent message from forwarding and saving.