pub struct GetFile { /* private fields */ }Expand description
Returns a basic information about a file and prepares it for downloading.
For the moment, bots can download files of up to 20MB in size.
The file can then be downloaded via the link
https://api.telegram.org/file/bot<token>/<file_path>,
where <file_path> is taken from the response.
It is guaranteed that the link will be valid for at least 1 hour.
When the link expires, a new one can be requested by calling GetFile again.
Notes
This function may not preserve the original file name and MIME type.
You should save the file’s MIME type and name (if available) when the File object is received.
Implementations