pub struct GetUserProfileAudios { /* private fields */ }Expand description
Returns a list of profile audios for a user.
Implementations
Sourceimpl GetUserProfileAudios
impl GetUserProfileAudios
Sourcepub fn with_limit(self, value: Integer) -> Self
pub fn with_limit(self, value: Integer) -> Self
Sets a new limit.
Arguments
value- Sequential number of the first audio to be returned.
By default, all audios are returned.
Sourcepub fn with_offset(self, value: Integer) -> Self
pub fn with_offset(self, value: Integer) -> Self
Sets a new offset
Arguments
value- Limits the number of audios to be retrieved.
Values between 1-100 are accepted. Defaults to 100.