pub struct InlineQueryResultCachedSticker { /* private fields */ }Expand description
Represents a link to a sticker stored on the Telegram servers.
By default, this sticker will be sent by the user.
Alternatively, you can use Self::with_input_message_content to
send a message with the specified content instead of the sticker.
Implementations
Sourceimpl InlineQueryResultCachedSticker
impl InlineQueryResultCachedSticker
Sourcepub fn new<A, B>(id: A, sticker_file_id: B) -> Self
pub fn new<A, B>(id: A, sticker_file_id: B) -> Self
Creates a new InlineQueryResultCachedSticker.
Arguments
id- Unique identifier of the result; 1-64 bytes.sticker_file_id- A valid file identifier of the sticker.
Sourcepub fn with_input_message_content<T>(self, value: T) -> Selfwhere
T: Into<InputMessageContent>,
pub fn with_input_message_content<T>(self, value: T) -> Selfwhere
T: Into<InputMessageContent>,
Sets a new input message content.
Arguments
value- Content of the message to be sent instead of the photo.
Sourcepub fn with_reply_markup<T>(self, value: T) -> Selfwhere
T: Into<InlineKeyboardMarkup>,
pub fn with_reply_markup<T>(self, value: T) -> Selfwhere
T: Into<InlineKeyboardMarkup>,