InlineQueryResultContact

Struct InlineQueryResultContact 

pub struct InlineQueryResultContact { /* private fields */ }
Represents a contact with a phone number.

By default, this contact will be sent by the user. Alternatively, you can use Self::with_input_message_content to send a message with the specified content instead of the contact.

Implementations

Source

impl InlineQueryResultContact

pub fn new<A, B, C>(first_name: A, id: B, phone_number: C) -> Self
where A: Into<String>, B: Into<String>, C: Into<String>,

Creates a new InlineQueryResultContact.

Arguments
  • first_name - Contact’s first name.
  • id - Unique identifier of the result; 1-64 bytes.
  • phone_number - Contact’s phone number.
pub fn with_input_message_content<T>(self, value: T) -> Self

Sets a new input message content.

Arguments
  • value - Content of the message to be sent instead of the contact.
pub fn with_last_name<T>(self, value: T) -> Self
where T: Into<String>,

Sets a new last name.

Arguments
  • value - Last name.
pub fn with_reply_markup<T>(self, value: T) -> Self

Sets a new reply markup.

Arguments
  • value - Reply markup.
pub fn with_thumbnail_height(self, value: Integer) -> Self

Sets a new thumbnail height.

Arguments
  • value - Thumbnail height.
pub fn with_thumbnail_url<T>(self, value: T) -> Self
where T: Into<String>,

Sets a new thumbnail URL.

Arguments
  • value - URL of the thumbnail for the result.
pub fn with_thumbnail_width(self, value: Integer) -> Self

Sets a new thumbnail width.

Arguments
  • value - Thumbnail width.
pub fn with_vcard<T>(self, value: T) -> Self
where T: Into<String>,

Sets a new vCard.

Arguments
  • value - Additional data about the contact in the form of a vCard; 0-2048 bytes.