pub struct InputProfilePhotoAnimated { /* private fields */ }Expand description
An animated profile photo in the MPEG4 format.
Implementations
Sourceimpl InputProfilePhotoAnimated
impl InputProfilePhotoAnimated
Sourcepub fn new<T>(animation: T) -> Self
pub fn new<T>(animation: T) -> Self
Creates a new InputProfilePhotoAnimated.
Arguments
animation- The animated profile photo; profile photos can’t be reused and can only be uploaded as a new file.
Sourcepub fn with_main_frame_timestamp(self, value: Float) -> Self
pub fn with_main_frame_timestamp(self, value: Float) -> Self
Sets a new main frame timestamp.
Arguments
value- Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.