pub struct LinkPreviewOptions {
pub is_disabled: Option<bool>,
pub prefer_large_media: Option<bool>,
pub prefer_small_media: Option<bool>,
pub show_above_text: Option<bool>,
pub url: Option<String>,
}Expand description
Represents the options used for link preview generation.
Fields
is_disabled: Option<bool>Whether the link preview is disabled.
prefer_large_media: Option<bool>Whether the media in the link preview is suppposed to be enlarged.
prefer_small_media: Option<bool>Whether the media in the link preview is suppposed to be shrunk.
show_above_text: Option<bool>Whether the link preview must be shown above the message text.
url: Option<String>URL to use for the link preview.
Implementations
Sourceimpl LinkPreviewOptions
impl LinkPreviewOptions
Sourcepub fn with_is_disabled(self, value: bool) -> Self
pub fn with_is_disabled(self, value: bool) -> Self
Sourcepub fn with_prefer_large_media(self, value: bool) -> Self
pub fn with_prefer_large_media(self, value: bool) -> Self
Sets a new value for the prefer_large_media flag.
Arguments
value- Whether the media in the link preview is suppposed to be enlarged; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview.
Sourcepub fn with_prefer_small_media(self, value: bool) -> Self
pub fn with_prefer_small_media(self, value: bool) -> Self
Sets a new value for the prefer_small_media flag.
Arguments
value- Whether the media in the link preview is suppposed to be shrunk; ignored if the URL isn’t explicitly specified or media size change isn’t supported for the preview.
Sourcepub fn with_show_above_text(self, value: bool) -> Self
pub fn with_show_above_text(self, value: bool) -> Self
Sets a new value for the show_above_text flag.
Arguments
value- Whether the link preview must be shown above the message text; otherwise, the link preview will be shown below the message text.