pub struct MessageOriginChannel {
pub chat: Chat,
pub date: Integer,
pub message_id: Integer,
pub author_signature: Option<String>,
}Expand description
The message was originally sent to a channel chat.
Fields
chat: ChatChat that sent the message originally.
date: IntegerDate the message was sent originally in Unix time.
message_id: IntegerUnique message identifier inside the chat.
Signature of the original post author.
Implementations
Sourceimpl MessageOriginChannel
impl MessageOriginChannel