pub struct MessageReactionUpdated {
pub chat: Chat,
pub date: Integer,
pub message_id: Integer,
pub new_reaction: Vec<ReactionType>,
pub old_reaction: Vec<ReactionType>,
pub actor_chat: Option<Chat>,
pub user: Option<User>,
}Expand description
Represents a change of a reaction on a message performed by a user.
Fields
chat: ChatThe chat containing the message the user reacted to.
date: IntegerDate of the change in Unix time.
message_id: IntegerUnique identifier of the message inside the chat.
new_reaction: Vec<ReactionType>New list of reaction types that have been set by the user.
old_reaction: Vec<ReactionType>Previous list of reaction types that were set by the user.
actor_chat: Option<Chat>The chat on behalf of which the reaction was changed, if the user is anonymous.
user: Option<User>The user that changed the reaction, if the user isn’t anonymous.
Implementations
Sourceimpl MessageReactionUpdated
impl MessageReactionUpdated
Sourcepub fn new<A, B, C>(
chat: A,
date: Integer,
message_id: Integer,
new_reaction: B,
old_reaction: C,
) -> Self
pub fn new<A, B, C>( chat: A, date: Integer, message_id: Integer, new_reaction: B, old_reaction: C, ) -> Self
Creates a new MessageReactionUpdated.
Arguments
chat- The chat containing the message the user reacted to.date- Date of the change in Unix time.message_id- Unique identifier of the message inside the chat.new_reaction- New list of reaction types that have been set by the user.old_reaction- Previous list of reaction types that were set by the user.
Sourcepub fn with_actor_chat<T>(self, value: T) -> Self
pub fn with_actor_chat<T>(self, value: T) -> Self
Sets a new actor chat.
Arguments
value- The chat on behalf of which the reaction was changed, if the user is anonymous.