pub struct PollOption {
pub persistent_id: String,
pub text: Text,
pub voter_count: Integer,
pub added_by_chat: Option<Chat>,
pub added_by_user: Option<User>,
pub addition_date: Option<Integer>,
pub media: Option<PollMedia>,
}Expand description
Represents an answer option in a poll.
Fields
persistent_id: StringUnique identifier of the option, persistent on option addition and deletion.
text: TextOption text; 1-100 characters.
voter_count: IntegerNumber of users that voted for this option.
added_by_chat: Option<Chat>Chat that added the option.
Omitted if the option wasn’t added by a chat after poll creation.
added_by_user: Option<User>User who added the option.
Omitted if the option wasn’t added by a user after poll creation.
addition_date: Option<Integer>Point in time (Unix timestamp) when the option was added.
Omitted if the option existed in the original poll.
media: Option<PollMedia>Media added to the poll option.
Implementations
Sourceimpl PollOption
impl PollOption
Sourcepub fn new<A, B>(persistent_id: A, text: B, voter_count: Integer) -> Self
pub fn new<A, B>(persistent_id: A, text: B, voter_count: Integer) -> Self
Creates a new PollOption.
Arguments
persistent_id- Unique identifier of the option.text- Option text; 1-100 characters.voter_count- Number of users that voted for this option.
Sourcepub fn with_added_by_chat<T>(self, value: T) -> Self
pub fn with_added_by_chat<T>(self, value: T) -> Self
Sourcepub fn with_added_by_user(self, value: User) -> Self
pub fn with_added_by_user(self, value: User) -> Self
Sourcepub fn with_addition_date(self, value: Integer) -> Self
pub fn with_addition_date(self, value: Integer) -> Self
Sourcepub fn with_media(self, value: PollMedia) -> Self
pub fn with_media(self, value: PollMedia) -> Self