pub struct ReadBusinessMessage { /* private fields */ }Expand description
Marks incoming message as read on behalf of a business account.
Requires the can_read_messages business bot right.
Implementations
Sourceimpl ReadBusinessMessage
impl ReadBusinessMessage
Sourcepub fn new<T>(
business_connection_id: T,
chat_id: Integer,
message_id: Integer,
) -> Self
pub fn new<T>( business_connection_id: T, chat_id: Integer, message_id: Integer, ) -> Self
Creates a new ReadBusinessMessage.
Arguments
business_connection_id- Unique identifier of the business connection on behalf of which to read the message.chat_id- Unique identifier of the chat in which the message was received; the chat must have been active in the last 24 hours.message_id- Unique identifier of the message to mark as read.