RepostStory

Struct RepostStory 

pub struct RepostStory { /* private fields */ }
Reposts a story on behalf of a business account from another business account.

Both business accounts must be managed by the same bot, and the story on the source account must have been posted (or reposted) by the bot.

Requires the can_manage_stories business bot right for both business accounts.

Implementations

Source

impl RepostStory

pub fn new<T>( active_period: Integer, business_connection_id: T, from_chat_id: Integer, from_story_id: Integer, ) -> Self
where T: Into<String>,

Creates a new RepostStory.

Arguments
  • active_period - Period after which the story is moved to the archive, in seconds; must be one of 6 * 3600, 12 * 3600, 86400, or 2 * 86400.
  • business_connection_id - Unique identifier of the business connection.
  • from_chat_id - Unique identifier of the chat which posted the story that should be reposted.
  • from_story_id - Unique identifier of the story that should be reposted.
pub fn with_post_to_chat_page(self, value: bool) -> Self

Sets a new value for the post_to_chat_page flag.

Arguments
  • value - Whether to keep the story accessible after it expires.
pub fn with_protect_content(self, value: bool) -> Self

Sets a new value for the protect_content flag.

Arguments
  • value - Whether the content of the story must be protected from forwarding and screenshotting.