pub struct SuggestedPostDeclined {
pub comment: Option<String>,
pub suggested_post_message: Option<Box<Message>>,
}Expand description
Describes a service message about the rejection of a suggested post.
Fields
comment: Option<String>Comment with which the post was declined.
suggested_post_message: Option<Box<Message>>Message containing the suggested post.
Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
Implementations
Sourceimpl SuggestedPostDeclined
impl SuggestedPostDeclined
Sourcepub fn with_comment<T>(self, value: T) -> Self
pub fn with_comment<T>(self, value: T) -> Self
Sourcepub fn with_suggested_post_message(self, value: Message) -> Self
pub fn with_suggested_post_message(self, value: Message) -> Self