SuggestedPostPrice

Struct SuggestedPostPrice 

pub struct SuggestedPostPrice {
    pub amount: Integer,
    pub currency: String,
}
Desribes price of a suggested post.

Fields

amount: Integer

The amount of the currency that will be paid for the post in the smallest units of the currency i.e. Telegram Stars or nanotoncoins.

Currently, price in Telegram Stars must be between 5 and 100000, and price in nanotoncoins must be between 10000000 and 10000000000000.

currency: String

Currency in which the post will be paid.

Currently, must be one of “XTR” for Telegram Stars or “TON” for toncoins.

Implementations

Source

impl SuggestedPostPrice

pub fn new<T>(amount: Integer, currency: T) -> Self
where T: Into<String>,

Creates a new SuggestedPostPrice.

Arguments
  • amount - The amount of the currency that will be paid for the post in the smallest units of the currency.
  • currency - Currency in which the post will be paid.