pub struct TransferGift { /* private fields */ }Expand description
Transfers an owned unique gift to another user.
Requires the can_transfer_and_upgrade_gifts business bot right.
Requires can_transfer_stars business bot right if the transfer is paid.
Implementations
Sourceimpl TransferGift
impl TransferGift
Sourcepub fn new<A, B>(
business_connection_id: A,
owned_gift_id: B,
new_owner_chat_id: Integer,
) -> Self
pub fn new<A, B>( business_connection_id: A, owned_gift_id: B, new_owner_chat_id: Integer, ) -> Self
Creates a new TransferGift.
Arguments
business_connection_id- Unique identifier of the business connection.owned_gift_id- Unique identifier of the regular gift that should be transferred.new_owner_chat_id- Unique identifier of the chat which will own the gift; the chat must be active in the last 24 hours.
Sourcepub fn with_star_count(self, value: Integer) -> Self
pub fn with_star_count(self, value: Integer) -> Self
Sets a new star count
Arguments
value- The amount of Telegram Stars that will be paid for the transfer from the business account balance; if positive, then the can_transfer_stars business bot right is required.