pub struct Voice {
pub duration: Integer,
pub file_id: String,
pub file_unique_id: String,
pub file_size: Option<Integer>,
pub mime_type: Option<String>,
}Expand description
Represents a voice file.
Fields
duration: IntegerDuration in seconds as defined by sender.
file_id: StringIdentifier of the file.
Can be used to download or reuse the file.
file_unique_id: StringUnique identifier of the file.
It is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
file_size: Option<Integer>File size in bytes.
mime_type: Option<String>MIME type as defined by sender.
Implementations
Sourceimpl Voice
impl Voice
Sourcepub fn new<A, B>(duration: Integer, file_id: A, file_unique_id: B) -> Self
pub fn new<A, B>(duration: Integer, file_id: A, file_unique_id: B) -> Self
Creates a new Voice.
Arguments
duration- Duration in seconds.file_id- Identifier of the file.file_unique_id- Unique identifier of the file.
Sourcepub fn with_file_size(self, value: Integer) -> Self
pub fn with_file_size(self, value: Integer) -> Self
Sourcepub fn with_mime_type<T>(self, value: T) -> Self
pub fn with_mime_type<T>(self, value: T) -> Self